@@ -132,7 +132,17 @@ FVP_MORELLO_ARGS = [
         ["--device", "fvp-morello-android", "--test", "multicore"],
         ["--device", "fvp-morello-android", *FVP_MORELLO_ARGS, "--tests", "bionic"],
         ["--device", "fvp-morello-android", *FVP_MORELLO_ARGS, "--tests", "lldb"],
-        ["--device", "fvp-morello-busybox", *FVP_MORELLO_ARGS, "--tests", "lldb"],
+        [
+            "--device",
+            "fvp-morello-busybox",
+            *FVP_MORELLO_ARGS,
+            "--tests",
+            "libjpeg-turbo",
+        ],
+        ["--device", "fvp-morello-busybox", *FVP_MORELLO_ARGS, "--tests", "libpng"],
+        ["--device", "fvp-morello-busybox", *FVP_MORELLO_ARGS, "--tests", "libpdfium"],
+        ["--device", "fvp-morello-busybox", *FVP_MORELLO_ARGS, "--tests", "zlib"],
+        ["--device", "fvp-morello-busybox", *FVP_MORELLO_ARGS, "--tests", "boringssl"],
         [
             "--device",
             "fvp-morello-busybox",
@@ -150,6 +160,42 @@ FVP_MORELLO_ARGS = [
             "--parameters",
             "LLDB_URL=http://example.com/lldb.tar.xz",
         ],
+        [
+            "--device",
+            "fvp-morello-android",
+            *FVP_MORELLO_ARGS,
+            "--tests",
+            "libpng",
+            "--parameters",
+            "SYSTEM_URL=http://example.com/system.tar.xz",
+        ],
+        [
+            "--device",
+            "fvp-morello-android",
+            *FVP_MORELLO_ARGS,
+            "--tests",
+            "libjpeg-turbo",
+            "--parameters",
+            "SYSTEM_URL=http://example.com/system.tar.xz",
+        ],
+        [
+            "--device",
+            "fvp-morello-android",
+            *FVP_MORELLO_ARGS,
+            "--tests",
+            "libpdfium",
+            "--parameters",
+            "SYSTEM_URL=http://example.com/system.tar.xz",
+        ],
+        [
+            "--device",
+            "fvp-morello-android",
+            *FVP_MORELLO_ARGS,
+            "--tests",
+            "libpdfium",
+            "--parameters",
+            "PDF_URL=http://example.com/pdfium-testfiles.tar.xz",
+        ],
     ],
 )
 def test_command_line_errors(argv, capsys, monkeypatch, mocker, artefacts):
