@@ -17,6 +17,7 @@ import sys
 import tempfile
 from urllib.parse import urlparse
 
+from tuxrun import templates
 from tuxrun.argparse import filter_options, pathurlnone, setup_parser
 from tuxrun.assets import get_rootfs, get_test_definitions
 from tuxrun.devices import Device
@@ -24,7 +25,6 @@ from tuxrun.exceptions import InvalidArgument
 from tuxrun.requests import requests_get
 from tuxrun.results import Results
 from tuxrun.runtimes import Runtime
-import tuxrun.templates as templates
 from tuxrun.utils import TTYProgressIndicator
 from tuxrun.writer import Writer
 from tuxrun.yaml import yaml_load
@@ -110,16 +110,16 @@ def run(options, tmpdir: Path) -> int:
         download(str(options.device_dict), (tmpdir / "device.yaml"))
         download(str(options.definition), (tmpdir / "definition.yaml"))
 
-    args = [
-        "lava-run",
-        "--device",
-        str(tmpdir / "device.yaml"),
-        "--job-id",
-        "1",
-        "--output-dir",
-        "output",
-        str(tmpdir / "definition.yaml"),
-    ]
+    # Render the dispatcher.yaml
+    (tmpdir / "dispatcher").mkdir()
+    dispatcher = (
+        templates.dispatchers()
+        .get_template("dispatcher.yaml.jinja2")
+        .render(prefix=tmpdir.name)
+    )
+    LOG.debug("dispatcher config")
+    LOG.debug(dispatcher)
+    (tmpdir / "dispatcher.yaml").write_text(dispatcher, encoding="utf-8")
 
     # Use a container runtime
     runtime = Runtime.select(options.runtime)()
@@ -143,20 +143,6 @@ def run(options, tmpdir: Path) -> int:
         if urlparse(path).scheme == "file":
             runtime.bind(path[7:], ro=True)
 
-    if options.device and options.device.startswith("fvp-") and runtime.container:
-        runtime.bind(f"{tmpdir}/dispatcher")
-        (tmpdir / "dispatcher").mkdir()
-        dispatcher = templates.dispatchers.get_template(
-            "dispatcher.yaml.jinja2"
-        ).render(prefix=f"{tmpdir}/dispatcher/")
-        LOG.debug("dispatcher config")
-        LOG.debug(dispatcher)
-
-        (tmpdir / "dispatcher.yaml").write_text(dispatcher, encoding="utf-8")
-        # Add dispatcher.yaml to the command line arguments
-        args.insert(-1, "--dispatcher")
-        args.insert(-1, str(tmpdir / "dispatcher.yaml"))
-
     # Forward the signal to the runtime
     def handler(*_):
         runtime.kill()
@@ -171,8 +157,24 @@ def run(options, tmpdir: Path) -> int:
     # start the pre_run command
     if options.device and options.device.startswith("fvp-"):
         LOG.debug("Pre run command")
+        runtime.bind(tmpdir / "dispatcher" / "tmp", "/var/lib/lava/dispatcher/tmp")
+        (tmpdir / "dispatcher" / "tmp").mkdir()
         runtime.pre_run(tmpdir)
 
+    # Build the lava-run arguments list
+    args = [
+        "lava-run",
+        "--device",
+        str(tmpdir / "device.yaml"),
+        "--dispatcher",
+        str(tmpdir / "dispatcher.yaml"),
+        "--job-id",
+        "1",
+        "--output-dir",
+        "output",
+        str(tmpdir / "definition.yaml"),
+    ]
+
     results = Results()
     # Start the writer (stderr or log-file)
     with Writer(options.log_file) as writer:
