@@ -7,9 +7,9 @@
 
 from typing import Dict, List, Optional
 
+from tuxrun import templates
 from tuxrun.devices import Device
 from tuxrun.exceptions import InvalidArgument
-import tuxrun.templates as templates
 
 
 class FVPDevice(Device):
@@ -53,18 +53,20 @@ class FVPDevice(Device):
             raise InvalidArgument("Invalid option for this fvp device: --rootfs")
 
     def definition(self, **kwargs):
+        kwargs = kwargs.copy()
+
         # Options that can *not* be updated
-        kwargs["prompts"] = self.prompts
-        kwargs["auto_login"] = self.auto_login
+        kwargs["prompts"] = self.prompts.copy()
+        kwargs["auto_login"] = self.auto_login.copy()
         kwargs["support_tests"] = self.support_tests
 
         kwargs["rootfs"] = self.rootfs if self.rootfs else kwargs.get("rootfs")
         kwargs["boot_timeout"] = self.boot_timeout
         # render the template
-        return templates.jobs.get_template("fvp.yaml.jinja2").render(**kwargs)
+        return templates.jobs().get_template("fvp.yaml.jinja2").render(**kwargs)
 
     def device_dict(self, context):
-        return templates.devices.get_template("fvp.yaml.jinja2").render(**context)
+        return templates.devices().get_template("fvp.yaml.jinja2").render(**context)
 
 
 class FVPMorelloAndroid(FVPDevice):
@@ -78,11 +80,25 @@ class FVPMorelloAndroid(FVPDevice):
         userdata_required = [
             t in tests for t in ["binder", "bionic", "compartment", "logd"]
         ]
+        system_required = [
+            t in tests
+            for t in ["libjpeg-turbo", "libpng", "libpdfium", "zlib", "boringssl"]
+        ]
         if any(userdata_required) and not parameters.get("USERDATA"):
             raise InvalidArgument(
                 "--parameters USERDATA=http://... is "
                 "mantadory for fvp-morello-android test"
             )
+        if any(system_required) and not parameters.get("SYSTEM_URL"):
+            raise InvalidArgument(
+                "--parameters SYSTEM_URL=http://... is "
+                f"mantadory for fvp-morello-android {system_required} test"
+            )
+        if "libjpeg-turbo" in tests and not parameters.get("LIBJPEG_TURBO_URL"):
+            raise InvalidArgument(
+                "--parameters LIBJPEG_TURBO_URL=http://... is "
+                "mantadory for fvp-morello-android libjpeg-turbo test"
+            )
         if "lldb" in tests and not parameters.get("LLDB_URL"):
             raise InvalidArgument(
                 "--parameters LLDB_URL=http://... is "
@@ -93,6 +109,16 @@ class FVPMorelloAndroid(FVPDevice):
                 "--parameters TC_URL=http://... is "
                 "mantadory for fvp-morello-android lldb test"
             )
+        if "libpng" in tests and not parameters.get("PNG_URL"):
+            raise InvalidArgument(
+                "--parameters PNG_URL=http://... is "
+                "mantadory for fvp-morello-android libpng test"
+            )
+        if "libpdfium" in tests and not parameters.get("PDFIUM_URL"):
+            raise InvalidArgument(
+                "--parameters PDFIUM_URL=http://... is "
+                "mantadory for fvp-morello-android libpdfium test"
+            )
 
 
 class FVPMorelloBusybox(FVPDevice):
